@@ -16,9 +16,10 @@
 # You should have received a copy of the GNU General Public License
 # along with Pylabeador.  If not, see <https://www.gnu.org/licenses/>.
 # -------------------------------------------------------------------------------------
+import pytest
 
 from pylabeador import WordProgress
-from pylabeador.syllabify import onset, nucleus
+from pylabeador.syllabify import nucleus, onset
 
 
 def test_onset():
@@ -42,3 +43,20 @@ def test_nucleus():
     assert onset_res == "h"
     nucleus_res = nucleus(w)
     assert nucleus_res == "ue"
+
+
+@pytest.mark.parametrize(
+    "word, syllable_to_check, expected_hyphenation, expected_nucleus",
+    [("paraguay", 3, "pa-ra-guay", "uay")],
+)
+def test_uncommon_nucleus(word, syllable_to_check, expected_hyphenation, expected_nucleus):
+    from pylabeador.syllabify import hyphenate
+
+    # Test the full hyphenation
+    result = hyphenate(word)
+    hyphenated = "-".join(s.value for s in result.syllables)
+    assert hyphenated == expected_hyphenation
+
+    # Test the specific syllable's nucleus
+    target_syllable = result.syllables[syllable_to_check - 1]  # Convert to 0-based index
+    assert target_syllable.nucleus == expected_nucleus
