@@ -23,17 +23,17 @@ from pylabeador import WordProgress
 def test_end():
     w = WordProgress("radio")
     w.pos = 3
-    assert w.char == 'i'
-    assert w.next() == 'o'
-    assert w.char == 'o'
+    assert w.char == "i"
+    assert w.next() == "o"
+    assert w.char == "o"
     assert not w.ended
     assert w.one_ahead is None
 
 
 def test_lookahead():
     w = WordProgress("que")
-    assert w.char == 'q'
-    assert w.one_ahead == 'u'
+    assert w.char == "q"
+    assert w.one_ahead == "u"
     w.next()
-    assert w.char == 'u'
-    assert w.one_ahead == 'e'
+    assert w.char == "u"
+    assert w.one_ahead == "e"
